# Track Types

```{eval-rst}
.. currentmodule:: mava_exchange

.. automodule:: mava_exchange.tracks
   :no-members:
   :no-index:
```

## Choosing a Track Type

- Use
  [**ObservationSeries**](../generated/mava_exchange.tracks.ObservationSeries.rst)
  for dense time-series
- Use
  [**AnnotationSeries**](../generated/mava_exchange.tracks.AnnotationSeries.rst)
  for single-label intervals
- Use
  [**AnnotationListSeries**](../generated/mava_exchange.tracks.AnnotationListSeries.rst)
  for multi-label intervals
